// Persistence of Vision Ray Tracer Scene Description File
// File: ?.pov
// Vers: 3.5
// Desc: Radiosity Scene Template
// Date: mm/dd/yy
// Auth: ?
//
#include "colors.inc"      
#include "textures.inc" 
#include "skies.inc"            
                     
#include "msac.inc"    
// this is file scI.pov
// anim params: +KI75 +KF81 +KFI0 +KFF150
// clock from 75 to 81
// frames from 0 to 150                    

#version 3.5;

#declare Radiosity=on;
#declare Photons=on;
                    
#declare O_Cloud3 =
sphere { <0,0,0>, 9999
    texture {
        T_Cloud3
        scale 1000
        scale <1,0.2,0.2>
    }
}
                    
                    
object{O_Cloud1 inverse}                    
//object{O_Cloud3}                    

global_settings {
  assumed_gamma 1.0
  max_trace_level 20
  #if (Photons)          // global photon block
    photons {
      spacing 0.05                 // specify the density of photons
      //count 100000               // alternatively use a total number of photons

      //gather min, max            // amount of photons gathered during render [20, 100]
      //media max_steps [,factor]  // media photons
      //jitter 1.0                 // jitter phor photon rays
      //max_trace_level 5          // optional separate max_trace_level
      //adc_bailout 1/255          // see global adc_bailout
      //save_file "filename"       // save photons to file
      //load_file "filename"       // load photons from file
      //autostop 0                 // photon autostop option
      //radius 10                  // manually specified search radius
      // (---Adaptive Search Radius---)
      //steps 1
      //expand_thresholds 0.2, 40
    }

  #end
  #if (Radiosity)
    radiosity {
      pretrace_start 0.08           // start pretrace at this size
      pretrace_end   0.04           // end pretrace at this size
      count 300                     // higher -> higher quality (1..1600) [35]
      nearest_count 7               // higher -> higher quality (1..10) [5]
      error_bound 1.8               // higher -> smoother, less accurate [1.8]
      recursion_limit 3             // how much interreflections are calculated (1..5+) [3]
      low_error_factor .5           // reduce error_bound during last pretrace step
      gray_threshold 0.0            // increase for weakening colors (0..1) [0]
      minimum_reuse 
      0.015           // reuse of old radiosity samples [0.015]
      brightness 1                  // brightness of radiosity effects (0..1) [1]

      adc_bailout 0.01/2
      //normal on                   // take surface normals into account [off]
      //media on                    // take media into account [off]
      //save_file "file_name"       // save radiosity data
      //load_file "file_name"       // load saved radiosity data
      //always_sample off           // turn sampling in final trace off [on]
      //max_sample 1.0              // maximum brightness of samples
    }
  #end
}

#default {
  texture {
    pigment {rgb 1}
    #if (Radiosity)
      finish {
        ambient 0.0
        diffuse 0.6
        specular 0.3
      }
    #else
      finish {
        ambient 0.1
        diffuse 0.6
        specular 0.3
      }
    #end
  }
}

// ----------------------------------------


sky_sphere {
  pigment {
    gradient y
    color_map {
      [0.0 rgb <0.6,0.7,1.0>]
      [0.7 rgb <0.0,0.1,0.8>]
    }
  }
}

// ----------------------------------------



              
 fog {
    distance 30
    color rgb<0.3, 0.5, 0.2>
    fog_type 2
    fog_offset 1
    fog_alt 0.6
    turbulence 0.3
    turb_depth 0.2     
 //   photons {pass_through on}
  }
  fog {
    distance 50
    color rgb<0.5, 0.1, 0.1>
    fog_type 2
    fog_offset 0.8
    fog_alt 0.8
    turbulence 0.3
    turb_depth 0.5
   // photons {pass_through on}
  }
  fog {
    distance 70
    color rgb<0.1, 0.1, 0.6>
    fog_type 2
    fog_offset 1.2
    turbulence 0.2
    turb_depth 0.5 
    fog_alt 0.5
  //  photons {pass_through on}
  }
  fog {
    distance 1000
    color rgb<0.5, 0.3, 0.7>
    fog_type 2
    fog_offset 100
    turbulence 0.2
    turb_depth 0.5 
    fog_alt 5
  //  photons {pass_through on}
  }
                
   #declare r_violet1 = color rgbf<1.0, 0.5, 1.0, 1.0>;
  #declare r_violet2 = color rgbf<1.0, 0.5, 1.0, 0.8>;
  #declare r_indigo  = color rgbf<0.5, 0.5, 1.0, 0.8>;
  #declare r_blue    = color rgbf<0.2, 0.2, 1.0, 0.8>;
  #declare r_cyan    = color rgbf<0.2, 1.0, 1.0, 0.8>;
  #declare r_green   = color rgbf<0.2, 1.0, 0.2, 0.8>;
  #declare r_yellow  = color rgbf<1.0, 1.0, 0.2, 0.8>;
  #declare r_orange  = color rgbf<1.0, 0.5, 0.2, 0.8>;
  #declare r_red1    = color rgbf<1.0, 0.2, 0.2, 0.8>;
  #declare r_red2    = color rgbf<1.0, 0.2, 0.2, 1.0>;
rainbow {
    angle 43
    width 2.5
    distance 1
    direction <-500,-300,150>
    jitter 0.01
    color_map {
      [0.000  color r_violet1 transmit 1]
      [0.100  color r_violet2 transmit 0.86]
      [0.214  color r_indigo  transmit 0.84]
      [0.328  color r_blue    transmit 0.82]
      [0.442  color r_cyan    transmit 0.80]
      [0.556  color r_green   transmit 0.82]
      [0.670  color r_yellow  transmit 0.84]
      [0.784  color r_orange  transmit 0.86]
      [0.900  color r_red1    transmit 0.88]
      [1.00  color r_red2  transmit 1]
    }
  //  photons {collect off}
  }

camera {
  right x*image_width/image_height
  location  <6,3,-8>
  look_at   <0,0.75,0>     
  rotate y*35*(clock-msac)
}

light_source {
  <500,300,-150>       // light's position
  color rgb 1.3       // light's color
  photons {           // photon block for a light source
    refraction on
    reflection on
  }
}


/*
plane {
  y, 0
  texture {
    pigment { checker rgb <1.0, 0.2, 0.2> rgb <0.2, 1.0, 0.2> }
  }
}
*/

plane {
  y, -1
  texture {
    pigment { color Blue }
  }
}


// create a superquadric ellipsoid shape
// As the exponents approach 1.0, the edges get rounder
#declare BiTile = union
{
superellipsoid {
  <0.1,  // east-west exponent (0.0 ... 1.0)
  0.1>   // north-south exponent (0.0 ... 1.0)
  scale <0.48,0.025,0.48>
  translate <0.5,-0.05,0.5>
  pigment {Jade}
}
superellipsoid {
  <0.1,  // east-west exponent (0.0 ... 1.0)
  0.1>   // north-south exponent (0.0 ... 1.0)
  scale <0.48,0.025,0.48>
  translate <-0.5,-0.05,0.5>
  pigment {Red_Marble}
}
superellipsoid {
  <0.1,  // east-west exponent (0.0 ... 1.0)
  0.1>   // north-south exponent (0.0 ... 1.0)
  scale <0.48,0.025,0.48>
  translate <-0.5,-0.05,-0.5>
  pigment {Jade}
}
superellipsoid {
  <0.1,  // east-west exponent (0.0 ... 1.0)
  0.1>   // north-south exponent (0.0 ... 1.0)
  scale <0.48,0.025,0.48>
  translate <0.5,-0.05,-0.5>
  pigment {Red_Marble}
}
}


#declare b2=-50;
#while (b2 <= 50)
#declare b1 = -50;
#while (b1 <= 50)
  object{BiTile translate b1*2*x+b2*2*z}
  #declare b1 = b1+1;   // increment our counter
#end
#declare b2 = b2+1;
#end






#declare M_Glass=    // Glass material
material {
  texture {
    pigment {rgbf <1,0.5,0.8,1>}
    finish {
      ambient 0.0
      diffuse 0.05
      specular 0.6
      roughness 0.005
      reflection {
        0.1, 1.0
        fresnel on
      }
      conserve_energy
    }
  }
  interior {
    ior 1.5
    fade_power 1001
    fade_distance 0.9
    fade_color <0.5,0.8,0.6>
  }
}

#declare R_Glass=    // Glass material
material {
  texture {
    pigment {rgbf <1,0.6,0.3,1>}
    finish {
      ambient 0.0
      diffuse 0.05
      specular 0.6
      roughness 0.005
      reflection {
        0.1, 1.0
        fresnel on
      }
      conserve_energy
    }
  }
  interior {
    ior 1.5
    fade_power 1001
    fade_distance 0.9
    fade_color <0.5,0.8,0.6>
  }
}



// torus {MAJOR, MINOR} // (in the X-Z plane)
// MAJOR = float value giving the major radius
// MINOR = float specifying the minor radius
// The major radius extends from the center of the hole
// to the mid-line of the rim while the minor radius
// is the radius of the cross-section of the rim.

union {

 torus {
  0.6,
  0.2
  pigment{color Red}
 translate -0.375*y
 rotate 90*z
 translate 2.8*y       
 rotate 180*y
  translate 1.3*1.05*abs(cos(1.398237/1.1025*(clock-msac)))*y
 }
 torus {
  0.6,
  0.2
  pigment{color Yellow}
  translate 0.75*y
 translate -0.375*y
 rotate 90*z
 translate 2.8*y       
 rotate 180*y
  translate 1.3*abs(cos(1.398237*(clock-msac)))*y
 }


sphere {
  <0,1,2>, 1
//  translate <2.0,0,2.3>
  material { M_Glass }

  photons {  // photon block for an object
    target 1.0
    refraction on
    reflection off
  }
  normal { // pattern for use in texture/pigment/normal/density
  bozo 0.5        // for use with normal{} (0...1 or more)
  turbulence 0.3  // turbulence often useful
   }
  translate 2*abs(cos(1.204895*(clock-msac)))*z

}

sphere {
  <0,1,-2>, 1
//  translate <2.0,0,2.3>
  material { R_Glass }

  photons {  // photon block for an object
    target 1.0
    refraction on
    reflection off
  }
  normal { // pattern for use in texture/pigment/normal/density
  bozo 0.5        // for use with normal{} (0...1 or more)
  turbulence 0.3  // turbulence often useful
   }
  translate -2*abs(cos(1.423895*(clock-msac)))*z

}


// create a superquadric ellipsoid shape
// As the exponents approach 1.0, the edges get rounder
superellipsoid {
  <0.2,  // east-west exponent (0.0 ... 1.0)
  0.2>   // north-south exponent (0.0 ... 1.0)
//  rotate 35*y
  translate y
//  translate <-2.2,1,1.8>
  texture { Gold_Texture normal {
  // pattern for use in texture/pigment/normal/density
// especially suited for normal {}
  dents 0.6    // dented surface (0...1 or more)
  //dents      // for use with pigment{}
  }
  }
  photons {  // photon block for an object
    target 1.0
    refraction off
    reflection on
  }
}

sphere {
  <0,0,0>, 1  

  normal {// pattern for use in texture/pigment/normal/density
// especially suited for normal {}
  wrinkles 0.5   // create a wrinkly surface (0...1 or more)
  //wrinkles      // for use with pigment{}
  } 
  pigment {
    // pattern for use in texture/pigment/normal/density
   crackle          // crackled pattern    
   scale 0.5
   translate (clock-msac)*z/3+<2,1,0>
  }
  rotate -z*2*abs(cos(1.07643*(clock-msac)))*(180/pi)
  translate <2,1,0>
  translate 2*abs(cos(1.07643*(clock-msac)))*x

}
         
 rotate 35*y

          
}
         
// uses image color index as height, extends along X-Z axes
// from <0 0 0> to <1 1 1>
height_field {
  tga               // the file type to read (tga/pot/pgm/ppm/png/sys)
  "ort.tga"     // the file name to read
 // smooth        // smooth surface normal
//  [water_level N] // truncate/clip below N (0.0 ... 1.0)
  texture { 
    pigment {
        // pattern for use in texture/pigment/normal/density
       gradient y         // specify gradient direction vector
  //gradient y, 0.5  // for use with normal{} (0...1 or more)
       // texture pigment {} attribute
// create a smooth color gradation map
color_map {
  //  [ END_VAL color red R green G blue B filter F transmit T]
  [ 0.0  color rgb <0.2,0.9,0.2>]
  [ 0.3  color rgb <0.1,0.6,0.1>]
  [ 0.5  color rgb <0.7,0.5,0.1>]
  [ 0.57  color rgb <0.6,0.3,0.0>]
  [ 0.7  color rgb <0.9,0.9,0.9>]
  [ 1.0  color rgb <1,1,1>]
  // (---alternative form---)
  //[ 1.0  color rgbf <0.8, 0.8, 0.8, 1.0> ]
} // color_map

      }
    }
//  translate VECTOR | rotate VECTOR | scale VECTOR  

  //translate <1,0,-0.5>
  scale <198,35,198>
  translate <-99,-2,99>
  
}

